## Replication script for "(When) Do Anti-poverty Programs Reduce Violence? India's Rural Employment Guarantee and Maoist Conflict"
## Aditya Dasgupta, Kishore Gawande, and Devesh Kapur

## Notes: All required files attached in enclosed folder. See readme.txt file for description of data sets and variable names.
## Once appropriate working directory is assigned, this R script should run in its entirety to produce all of the main figures
## and tables in the paper. All required packages listed below and may need to be installed. 

## Working directory
####################

rm(list=ls())
setwd("ENTER WORKING DIRECTORY HERE") ## Set to working directory with enclosed data

## Load data
############

load("DAT.RData")
load("BALANCE.RData")
load("QUARTERLY_DAT.RData")
load("INDIA.RData")

## Libraries and functions
##########################

library(maptools) # mapping shapefiles 
library(stargazer) ## for tables
library(xtable) ## for tables
cl <- function(dat,fm, cluster){ ## Cluster robust standard error
           require(sandwich, quietly = TRUE)
           require(lmtest, quietly = TRUE)
           M <- length(unique(cluster))
           N <- length(cluster)
           K <- fm$rank
           dfc <- (M/(M-1))*((N-1)/(N-K))
           uj  <- apply(estfun(fm),2, function(x) tapply(x, cluster, sum));
           vcovCL <- dfc*sandwich(fm, meat=crossprod(uj)/N)
}
describe <- function(x,data){ ## Descriptive statistics
	full <- na.omit(data[,x])
	within <- na.omit(do.call("c",tapply(data[,x], data$district, function(x){
		x-mean(x,na.rm=T)})))
	c(mean(full), sd(full), sd(within), quantile(full, c(.05,.25,.5,.75,.95)))
}

## Figure 1: Maoist Conflict Violence Over Time, 1999-2009
##########################################################

pdf(file="figure1.pdf",width=10,height=10) ## Will output plot as pdf file to working directory
plot(1999:2009,tapply(dat$totaldeaths, dat$year, sum),type='l',
	ylim=c(100,1300), xlab="Year", ylab="Total")
legend("topleft", c("Deaths","Incidents"), lty=c(1,2))
points(1999:2009,tapply(dat$totaldeaths, dat$year, sum),pch=20)
points(1999:2009,tapply(dat$incident, dat$year, sum),pch=21)
points(1999:2009,tapply(dat$incident, dat$year, sum),type='l',lty=2)
dev.off()

## Figure 2: Average Quarterly Deaths from Maoist Conflict By District, 1999-2009
#################################################################################

jpeg(file="plot2.jpg", width=1000, height=1000) ## Will output plot as jpeg file to working directory
colcode <- c("#DEDEDE","#C6C6C6","#A7A7A7","#868686","#686868","#484848","#202020","#000000")[india@data$col]
plot(india, col=colcode, xlab="", ylab="")
legend("bottomleft", c("(0,0.0909]","(0.0909,0.273]","(0.273,0.909]","(0.909,1.51]","(1.51,3.44]","(3.44,7.18]","(7.18,12.4]","(12.4,125]") , 
	fill=c("#DEDEDE","#C6C6C6","#A7A7A7","#868686","#686868","#484848","#202020","#000000"), cex=1.5)
dev.off()

## Figure 3: Districts by NREGS Adoption Phase
##############################################

jpeg(file="plot3.jpg", width=1000, height=1000) ## Will output plot as jpeg file to working directory
india@data$PHASE <- ifelse(india@data$STATE_UT%in%c("Andhra Pradesh","Bihar","Chhattisgarh",
	"Jharkhand","Orissa","West Bengal"),india@data$PHASE,NA)
plot(india, col=ifelse(india@data$PHASE==1,"darkgray",
	ifelse(india@data$PHASE==2,"#484848", "#000000")), xlab="", ylab="")
legend("bottomleft", legend=c("Phase 1","Phase 2","Phase 3"), 
	fill=c("darkgray","#484848", "#000000"), cex=2)
dev.off()

## Table 1: Balance on Covariates Across NREGS Phases Before and After Controls
###############################################################################

lm0a <- lm((sc_share + st_share) ~ as.factor(PHASE), data=balance)
lm0b <- lm((sc_share + st_share) ~ as.factor(PHASE) + BI + LWE, data=balance)
lm0c <- lm(wage_new ~ as.factor(PHASE), data=balance)
lm0d <- lm(wage_new ~ as.factor(PHASE) + BI + LWE, data=balance)
lm0e <- lm(previolence0005 ~ as.factor(PHASE), data=balance)
lm0f <- lm(previolence0005 ~ as.factor(PHASE) + BI + LWE, data=balance)
stargazer(lm0a,lm0b,lm0c,lm0d,lm0e,lm0f)

## Table 2: Descriptive Statistics
##################################

tab2a <- rbind(describe("incident",quarterly_dat),describe("totaldeaths",quarterly_dat),describe("civiliancasualty",quarterly_dat),
	describe("maoistcasualty",quarterly_dat),describe("securitycasualty",quarterly_dat), 
		describe("NREGS",quarterly_dat), describe("BI",quarterly_dat),describe("LWE",quarterly_dat),
			describe("rain_series",quarterly_dat))
rownames(tab2a) <- c("Incidents","Total Deaths","Civilian Deaths","Maoist Deaths","Security Deaths",
	"NREGS","BI","LWE","Rainfall")
tab2b <- rbind(describe("intensity",quarterly_dat), describe("ranking",quarterly_dat))
rownames(tab2b) <- c("Intensity","Ranking")
tab2 <- rbind(tab2a,tab2b)
colnames(tab2) <- c("Mean","SD","Within-SD","5%","25%","50%","75%","95%")
xtable(tab2)

## Table 3: Poisson Regression Estimates of NREGS Effect on Maoist Conflict Violence
#####################################################################################

## Incidents

## Baseline

lm1a <- glm(incident ~ NREGS + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE,
		family="quasipoisson", data=quarterly_dat)
vcovlm1a <- cl(model.frame(lm1a), lm1a, model.frame(lm1a)[,3])

## Lag NREGS

lm1a2 <- glm(incident ~ NREGS + NREGS1 + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE,
		family="quasipoisson", data=quarterly_dat)
vcovlm1a2 <- cl(model.frame(lm1a2), lm1a2, model.frame(lm1a2)[,4])

## Dependent variable lag

lm1b <- glm(incident ~ NREGS + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE + incidentLAG1,
	family="quasipoisson", data=quarterly_dat)
vcovlm1b <- cl(model.frame(lm1b), lm1b, model.frame(lm1b)[,3])

## Neighboring districts

lm1c <- glm(incident ~ NREGS + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE + spatial, family="quasipoisson",
			data=quarterly_dat)
vcovlm1c <- cl(model.frame(lm1c), lm1c, model.frame(lm1c)[,3])

## State-year FE

lm1d <- glm(incident ~ NREGS + as.factor(district) + as.factor(year):as.factor(state) + 
	as.factor(year):BI + as.factor(year):LWE,family="quasipoisson",
		data=quarterly_dat)
vcovlm1d <- cl(model.frame(lm1d), lm1d, model.frame(lm1d)[,3])

## Deaths

## Baseline

lm1ab <- glm(totaldeaths ~ NREGS + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE,
		family="quasipoisson", data=quarterly_dat)
vcovlm1ab <- cl(model.frame(lm1ab), lm1ab, model.frame(lm1ab)[,3])

## Lag NREGS

lm1ab2 <- glm(totaldeaths ~ NREGS + NREGS1 + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE,
		family="quasipoisson", data=quarterly_dat)
vcovlm1ab2 <- cl(model.frame(lm1ab2), lm1ab2, model.frame(lm1ab2)[,4])

## Dependent variable lag

lm1bb <- glm(totaldeaths ~ NREGS + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE + deathLAG1,
	family="quasipoisson", data=quarterly_dat)
vcovlm1bb <- cl(model.frame(lm1bb), lm1bb, model.frame(lm1bb)[,3])

## Neighboring districts

lm1cb <- glm(totaldeaths ~ NREGS + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE + spatial, family="quasipoisson",
			data=quarterly_dat)
vcovlm1cb <- cl(model.frame(lm1cb), lm1cb, model.frame(lm1cb)[,3])

## State-year FE

lm1db <- glm(totaldeaths ~ NREGS + as.factor(district) + as.factor(year):as.factor(state) + 
	as.factor(year):BI + as.factor(year):LWE, family="quasipoisson",
		data=quarterly_dat)
vcovlm1db <- cl(model.frame(lm1db), lm1db, model.frame(lm1db)[,3])

## Output

stargazer(coeftest(lm1a,vcov.=vcovlm1a),coeftest(lm1a2,vcov.=vcovlm1a2),coeftest(lm1b,vcov.=vcovlm1b),coeftest(lm1c,vcov.=vcovlm1c),
	coeftest(lm1d,vcov.=vcovlm1d), coeftest(lm1ab,vcov.=vcovlm1ab),coeftest(lm1ab2,vcov.=vcovlm1ab2), coeftest(lm1bb,vcov.=vcovlm1bb),coeftest(lm1cb,vcov.=vcovlm1cb),
	coeftest(lm1db,vcov.=vcovlm1db),omit=c("STYR","state","district","BI","year","index","LWE"))


## Table 4: State Capacity and the Heterogeneous Effects of NREGS on Violence
#############################################################################

lm4b <- glm(incident ~ NREGS + I(intensity*NREGS) + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE + I(wage_new*NREGS) + I(irr*NREGS) +
		I(scst*NREGS) + I(previolence*NREGS), family="quasipoisson",
			data=quarterly_dat)
vcovlm4b <- cl(model.frame(lm4b), lm4b, model.frame(lm4b)[,4])
coeftest(lm4b, vcov.=vcovlm4b)

lm4d <- glm(incident ~ NREGS + I(top*NREGS) + I(second*NREGS) + I(third*NREGS) + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE + I(wage_new*NREGS) + I(irr*NREGS) +
		I(scst*NREGS)+ I(previolence*NREGS), family="quasipoisson",
			data=quarterly_dat)
vcovlm4d <- cl(model.frame(lm4d), lm4d, model.frame(lm4d)[,6])
coeftest(lm4d, vcov.=vcovlm4d)

lm4f <- glm(totaldeaths ~ NREGS + I(intensity*NREGS) + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE + I(wage_new*NREGS) + I(irr*NREGS) +
		I(scst*NREGS)+ I(previolence*NREGS), family="quasipoisson",
		data=quarterly_dat)
vcovlm4f <- cl(model.frame(lm4f), lm4f, model.frame(lm4f)[,4])
coeftest(lm4f, vcov.=vcovlm4f)

lm4h <- glm(totaldeaths ~ NREGS + I(top*NREGS) + I(second*NREGS) + I(third*NREGS) + as.factor(district) + as.factor(year) + 
	as.factor(year):BI + as.factor(year):LWE + I(wage_new*NREGS) + I(irr*NREGS) +
		I(scst*NREGS)+ I(previolence*NREGS), family="quasipoisson",
		data=quarterly_dat)
vcovlm4h <- cl(model.frame(lm4h), lm4h, model.frame(lm4h)[,6])
coeftest(lm4h, vcov.=vcovlm4h)

stargazer(coeftest(lm4b,vcov.=vcovlm4b),coeftest(lm4d,vcov.=vcovlm4d),
	coeftest(lm4f,vcov.=vcovlm4f),coeftest(lm4h,vcov.=vcovlm4h),
			omit=c("STYR","state","district","BI","year"))

## Figure 4: Changes in Violence Before and After NREGS Adoption by Quarter-year
################################################################################

lm2a <- glm(incident ~ tminus8 + tminus7 + tminus6 + tminus5 + 
	tminus4 + tminus3 + tminus2 + tminus1 + t + tplus1 + 
	tplus2 + tplus3 + tplus4 + tplus5 + tplus6 + tplus7onward + as.factor(district) +
		as.factor(year) + BI:as.factor(year) + LWE:as.factor(year), 
			family="quasipoisson", data=quarterly_dat)
vcovlm2a <- cl(model.frame(lm2a), lm2a, model.frame(lm2a)[,18])
points <- coefficients(lm2a)[2:17]
se <- sqrt(diag(vcovlm2a)[2:17])

lm2b <- glm(totaldeaths ~ tminus8 + tminus7 + tminus6 + tminus5 + 
	tminus4 + tminus3 + tminus2 + tminus1 + t + tplus1 + 
	tplus2 + tplus3 + tplus4 + tplus5 + tplus6 + tplus7onward + as.factor(district) +
		as.factor(year) + BI:as.factor(year) + LWE:as.factor(year), 
			family="quasipoisson", data=quarterly_dat)
vcovlm2b <- cl(model.frame(lm2b), lm2b, model.frame(lm2b)[,18])
pointsb <- coefficients(lm2b)[2:17]
seb <- sqrt(diag(vcovlm2b)[2:17])

pdf(file="plot4.pdf",width=10,height=10) ## Will output plot as pdf file to working directory
par(mfrow=c(2,1))
plot(points, ylim=c(-5,2), xaxt="n", 
	ylab="Coefficient",xlab="Quarter Years from NREGS Adoption",
		cex=2, pch=20,main="Outcome: Total Incidents")
points(points, type='l')
segments(x0=1:(length(points)-1),x1=2:length(points),
	y0=points[1:15]-1.96*se[1:15],y1=points[2:16]-1.96*se[2:16],lty=3)
segments(x0=1:(length(points)-1),x1=2:length(points),
	y0=points[1:15]+1.96*se[1:15],y1=points[2:16]+1.96*se[2:16],lty=3)
abline(h=0,lty=2)
axis(1, at=1:length(points), labels=c("T-8","T-7","T-6","T-5","T-4","T-3","T-2","T-1","T","T+1","T+2","T+3",
	"T+4","T+5","T+6","T+7"))

plot(pointsb, ylim=c(-5,2), xaxt="n", 
	ylab="Coefficient",xlab="Quarter Years from NREGS Adoption",
		cex=2, pch=20,main="Outcome: Total Deaths")
points(pointsb, type='l')
segments(x0=1:(length(pointsb)-1),x1=2:length(pointsb),
	y0=pointsb[1:15]-1.96*seb[1:15],y1=pointsb[2:16]-1.96*seb[2:16],lty=3)
segments(x0=1:(length(pointsb)-1),x1=2:length(pointsb),
	y0=pointsb[1:15]+1.96*seb[1:15],y1=pointsb[2:16]+1.96*seb[2:16],lty=3)
abline(h=0,lty=2)
axis(1, at=1:length(pointsb), labels=c("T-8","T-7","T-6","T-5","T-4","T-3","T-2","T-1","T","T+1","T+2","T+3",
	"T+4","T+5","T+6","T+7"))
dev.off()

## Table 5: Rainfall Shocks and Heterogeneous Effects of NREGS on Violence
##########################################################################

## Poisson: Violence Data

lm5a <- glm(incident ~ NREGS + rain_series + I(rain_series*NREGS) + 
	as.factor(district) + as.factor(year) + as.factor(year):BI + as.factor(year):LWE,
		family="quasipoisson", data=quarterly_dat)
vcovlm5a <- cl(model.frame(lm5a), lm5a, model.frame(lm5a)[,5])

lm5b <- glm(totaldeaths ~ NREGS + rain_series + I(rain_series*NREGS) + 
	as.factor(district) + as.factor(year) + as.factor(year):BI + as.factor(year):LWE,
		family="quasipoisson", data=quarterly_dat)
vcovlm5b <- cl(model.frame(lm5b), lm5b, model.frame(lm5b)[,5])

## OLS: Administrative Data

lm5c <- lm(totaldays ~ rain1_series + as.factor(district) + as.factor(year),
	data=dat[dat$NREGS==1,])
vcovlm5c <- cl(model.frame(lm5c), lm5c, model.frame(lm5c)[,3])

lm5d <- lm(expenditure ~ rain1_series + as.factor(district) + as.factor(year),
	data=dat[dat$NREGS==1,]) 
vcovlm5d <- cl(model.frame(lm5d), lm5d, model.frame(lm5d)[,3])

stargazer(coeftest(lm5a,vcov.=vcovlm5a),coeftest(lm5b,vcov.=vcovlm5b),
	coeftest(lm5c,vcov.=vcovlm5c),coeftest(lm5d,vcov.=vcovlm5d), 
		omit=c("STYR","state","district","BI","year","LWE"))

## END
######
